# clams-utils

Repository that holds a collection of smaller helper/utility code of CLAMS platform.
Use PyPI release to install the package. 

``` bash 
pip install clams-utils
```

## Usage
At the moment, the package contains the following packages and modules:

* `clams_utils.aapb`: package that contains helper functions for AAPB data
    * `goldretriver`: downloader module for "gold" release data from [`aapb-annotation`](https://github.com/clamsproject/aapb-annotations) repository. 



